/***
*****************************************************************************************************************************************
Depression, Risk Preferences and Risk-taking Behavior
Cobb-Clark, Dahmann, Kettlewell

											CORRELATION BETWEEN MCS INDICATOR AND SELF-REPORTED DEPRESSION
*****************************************************************************************************************************************

This code computes the correlation between the MCS depression indicator and self-reported diagnosed depression.
It requires the dataset "cleandata.dta" generated by data.do to be stored in the project folder and the original SOEP data in long format.
***/

***PLEASE ADJUST PATHS***
global soeplong ...SOEP-LONG_v33.1i_stata_bilingual\	//Path where SOEP data is stored in long format
global project ...\										//Path where project data is saved


set more off

***********************************************************************************************
* Load data and select sample
***********************************************************************************************

use "${project}cleandata.dta", clear
merge 1:1 pid syear using ${soeplong}pl.dta, keepusing(ple0019)

g miss_control = 0
foreach var of varlist male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn {
	replace miss_control = 1 if `var' ==.
}
drop if miss_control==1

replace ple0019=0 if ple0019==-2
replace ple0019=. if ple0019<0
rename ple0019 depression

keep pid syear mcs_dummy depression
drop if syear<2002

***********************************************************************************************
* Compute prevalence and correlation
***********************************************************************************************

bys pid: egen max_depression=max(depression)
bys pid: egen max_mcs=max(mcs_dummy)

keep pid max*
duplicates drop
corr max_depression max_mcs
ta max_mcs max_depression, row
tetrachoric max_mcs max_depression