/***
*****************************************************************************************************************************************
Depression, Risk Preferences and Risk-taking Behavior
Cobb-Clark, Dahmann, Kettlewell

											DESCRIPTIVE STATISTICS FOR THE MAIN SOEP SAMPLE
*****************************************************************************************************************************************

This code creates Table A5 in the paper.
It requires the dataset "cleandata.dta" generated by data.do to be stored in the project folder and the original SOEP data in long format.
***/

***PLEASE ADJUST PATHS***
global project ...\										//Path where project data is saved

use "${project}cleandata.dta", clear

local controls male age lhh_inc edu_high paredu hh_type1 hh_type2 hh_type3 hh_type4 hh_type5 hh_type6 hh_type7 hh_type8 germborn

//=============
//Summary stats
//=============

g miss_control = 0
foreach var in `controls' mcs_dummy {
	replace miss_control = 1 if `var' ==.
}

keep if mcs_dummy!=.&miss_control==0
local vars `controls' r_gen r_drive r_fin r_sport r_occup r_health r_trust 
local rows = wordcount("`vars'")

matrix output = J(`rows',6,0) 

foreach var in `vars' {
	forvalues j = 1/`rows' {
		if word("`vars'", `j') == "`var'" local i = `j'
	}
	qui reg `var' mcs_dummy, cl(pid)
	mat diff_table=r(table)
	matrix output[`i',1] = _b[_cons] 
	matrix output[`i',3] = _b[_cons]+_b[mcs_dummy]
	matrix output[`i',5] = _b[mcs_dummy]
	matrix output[`i',6] = diff_table[4,1]
	qui count if mcs_dummy==0&e(sample)
	matrix output[`i',2] = r(N) 
	qui count if mcs_dummy==1&e(sample)
	matrix output[`i',4] = r(N)
}

mat colnames output= mean_mcs0 n1 mean_mcs1 n2 diff pval
mat rownames output= `vars' 
mat list output, f(%9.3f)

putexcel set descriptive_stats_SOEP, replace
putexcel A1 = matrix(output), names

